// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef APP_WINDOW_H
#define APP_WINDOW_H

#include "mtp_device.h"

#include <gtkmm/window.h>
#include <gtkmm/statusbar.h>
#include <gtkmm/progressbar.h>
#include <gtkmm/toolbar.h>
#include <gtkmm/uimanager.h>
#include <gtkmm/paned.h>
#include <gtkmm/scrolledwindow.h>
#include <gudev/gudev.h>

class PlaylistView;
class MusicView;

namespace Playedit
{

class App : public Gtk::Window
{
	public:
		App();
		~App();

		void SetStatus(const Glib::ustring& message);
		void UnsetStatus();
		void SetProgress(const gdouble fraction);

		void PlaylistClearTrack(uint32_t track_id);

		Glib::RefPtr<Gtk::UIManager> m_UIManager;
		MTPDevice m_Device;

	private:
		void QuitPlayedit();
		void CreateUIManager();
		Gtk::Toolbar* GetMusicToolbar();
		Gtk::Toolbar* GetPlaylistToolbar();

		static void UEventCB(GUdevClient *client, const char *action, GUdevDevice *device,
				Playedit::App* app_window);
		void ConnectDevice(int devnum);
		void DisconnectDevice();
		void RenameDevice();

		void ProcessPending();
		static int PulseProgress(const uint64_t received, const uint64_t total,
				const void* data);

		Gtk::Box m_Box;
		Gtk::Paned m_Paned;

		// The music view
		MusicView* m_MusicView;
		Gtk::Box m_MusicBox;
		Gtk::ScrolledWindow m_MusicViewport;

		// The playlist view
		PlaylistView* m_PlaylistView;
		Gtk::Box m_PlaylistBox;
		Gtk::ScrolledWindow m_PlaylistViewport;

		Gtk::Statusbar m_Statusbar;
		Gtk::ProgressBar m_Progress;
		Glib::RefPtr<Gtk::ActionGroup> m_DeviceInteractionGroup;
		Glib::RefPtr<Gtk::ActionGroup> m_DeviceActionGroup;

		GUdevClient *m_GUDevClient;
};

}

#endif // APP_WINDOW_H
